# Communication and Signal Processing: MIMO
### M.Sc. Vladimir Fadeev

**Additional teaching materials for the [Communication and Signal Processing (CSP)](https://griat.kai.ru/communications-and-signal-processing) major of German-Russian Institute of Advanced Technologies (GRIAT): Multiple Input Multiple Output (MIMO) technology.**

![](https://habrastorage.org/webt/1p/1j/7t/1p1j7tpczw6es1rnah6ij0dlujo.png)

## Summary

- Desirable background:
   * [Rician flat fading (SISO)](https://nbviewer.jupyter.org/github/kirlf/CSP/blob/master/MIMO/RicianFlatFadingMATLAB.ipynb) 
- Tutorials:
    * [MIMO channel capacity](https://nbviewer.jupyter.org/github/kirlf/CSP/blob/master/MIMO/MIMO%20Capacity.ipynb) 
    * [Space-Time Codes (Alamouti)](https://nbviewer.jupyter.org/github/kirlf/CSP/blob/master/MIMO/Alamouti.ipynb) 
- Self-education:
    * [Spatial correlation (tasks)](https://nbviewer.jupyter.org/github/kirlf/CSP/blob/master/MIMO/Spatial_Correlation.ipynb)


## Preface

This work is prepared for students of **MS-CSP** (**C**ommunication and **S**ignal **P**rocessing) program (GRIAT) primarily. However, everyone who is interested in considered topics is welcome!

## Motivation

Why should you learn MIMO technology basics?

MIMO is a part of the most of modern wireless communication standards. For example, this is implemented in **LTE/LTE-A** networks and in Wi-Fi devices since **802.11n** (Wi-Fi 4).

Moreover, the evolution of the MIMO - Massive MIMO is a part of the **5G** networks. This fact means scientific interest, and science is impossible without basics.

<img src="https://base.imgix.net/files/base/ebm/mwrf/image/2018/09/www_mwrf_com_sites_mwrf.com_files_1018_40P_Fig3.png?auto=format&fit=max&w=1440" width="600" />

> [Realizing 5G Sub-6-GHz Massive MIMO Using GaN](https://www.mwrf.com/semiconductors/realizing-5g-sub-6-ghz-massive-mimo-using-gan)

Additionally, MIMO topic is a good opportunity to train your **linear algebra** skills!

## Suggested literature

   * Paulraj, Arogyaswami, Rohit Nabar, and Dhananjay Gore. Introduction to space-time wireless communications. Cambridge university press, 2003.
   * Salehi, M., and J. Proakis. "Digital communications." McGraw-Hill Education 31 (2007): 32.
   * Haykin, Simon S. Digital communications. New York: Wiley, 1988.
   * Goldsmith, Andrea. [Wireless communications.](http://wsl.stanford.edu/~andrea/Wireless/Book.pdf) Cambridge university press, 2005.
   * Sklar, Bernard. Digital communications: fundamentals and applications. 2001.

## See also

The work on this project inspired me to write several popular science articles in my native language. Probably, it can be also helpful for someone:
   
   * [Оцениваем пропускную способность MIMO канала (алгоритм Water-pouring прилагается)](https://habr.com/ru/post/448570/)
   * [MU-MIMO: один из алгоритмов реализации](https://habr.com/ru/post/450948/)
   * [MIMO spatial diversity: Аламоути, DET и прочее пространственное разнесение](https://habr.com/ru/post/452494/)
   * [Почти самый простой MIMO канал с замираниями (модель Кронекера прилагается)](https://habr.com/ru/post/447172/)

And several matherials about adaptive and array signal processing:
   * [Adaptive beamforming](https://gist.github.com/kirlf/afa2ac6fc0acb93edb7984c9bb1d6e63) (Python 3 source code)
   * [Adaptive filters](https://gist.github.com/kirlf/8e77cc17b7b1be4e35dbf651ff82f759) (Python 3 / MATLAB source codes)
   * [Моделируем алгоритм MUSIC для задач определения направления прихода электромагнитной волны](https://habr.com/ru/post/446674/)
   * [Оптимальная линейная фильтрация: от метода градиентного спуска до адаптивных фильтров](https://habr.com/ru/post/455497/)

## Comments and feedback

I'll be appreciate your **stars** because in my oppinion this is one of the brightest indicators of a good work!

You also can send your comments and suggestion by e-mail: vovenur@gmail.com

The feedback is valuable for me!

Have a nice reading, good day, and good luck!

M.Sc. Vladimir Fadeev
